@@ -1,3 +1,4 @@
+import shlex
 from abc import ABCMeta, abstractmethod
 from pathlib import Path
 from typing import Iterable, Union
@@ -24,8 +25,12 @@ class ArchivePackage(ManualPackage, metaclass=ABCMeta):
     async def archive_url(self) -> str:
         pass
 
+    @property
+    def pathname(self) -> str:
+        return self.name.replace("/", "--")
+
     async def package_directory(self) -> Path:
-        result = (await self.local()) / "mybox" / self.name.replace("/", "--")
+        result = (await self.local()) / "mybox" / self.pathname
         await self.driver.makedirs(result)
         return result
 
@@ -53,6 +58,19 @@ class ArchivePackage(ManualPackage, metaclass=ABCMeta):
             "unzip", "-o", "-qq", source, "-d", await self.package_directory()
         )
 
+    async def appimage(self, source: Path) -> None:
+        async with self.driver.tempfile() as target:
+            await self.driver.run("cp", source, target)
+            await self.driver.make_executable(target)
+
+            cmd = " && ".join(
+                [
+                    shlex.join(["cd", str(await self.package_directory())]),
+                    shlex.join([str(target), "--appimage-extract"]),
+                ]
+            )
+            await self.driver.run("sh", "-c", cmd)
+
     async def extract(self, url: str, source: Path) -> None:
         if self.raw:
             if isinstance(self.raw, str):
@@ -73,28 +91,47 @@ class ArchivePackage(ManualPackage, metaclass=ABCMeta):
             await self.untar(source, "-J")
         elif url.endswith(".zip"):
             await self.unzip(source)
+        elif url.endswith(".AppImage"):
+            await self.appimage(source)
         else:
             raise ValueError(f"Unknown archive format: {url}")
 
-    async def binary_path(self, binary: str) -> Path:
-        paths: list[list[str]] = [[], ["bin"]]
+    async def find_in_package_directory(
+        self,
+        paths: list[list[str]],
+        name: str,
+        *,
+        require_executable: bool = False,
+        target_desc: str,
+    ) -> Path:
         for relative_path in paths:
-            candidate = await self.package_directory() / Path(*relative_path) / binary
-            if await self.driver.is_executable(candidate):
+            candidate = await self.package_directory() / Path(*relative_path) / name
+            if require_executable:
+                candidate_ok = await self.driver.is_executable(candidate)
+            else:
+                candidate_ok = await self.driver.is_file(candidate)
+            if candidate_ok:
                 return candidate
-        raise ValueError(f"Cannot find {binary} in {await self.package_directory()}.")
+        raise ValueError(
+            f"Cannot find {target_desc} '{name}' in {await self.package_directory()}."
+        )
+
+    async def binary_path(self, binary: str) -> Path:
+        appimage_candidate = await self.package_directory() / "squashfs-root" / "AppRun"
+        if await self.driver.is_executable(appimage_candidate):
+            return appimage_candidate
+        return await self.find_in_package_directory(
+            paths=[[], ["bin"]],
+            name=binary,
+            require_executable=True,
+            target_desc="binary",
+        )
 
     async def app_path(self, name: str) -> Path:
-        candidate = (
-            await self.package_directory()
-            / "share"
-            / "applications"
-            / f"{name}.desktop"
-        )
-        if await self.driver.is_file(candidate):
-            return candidate
-        raise ValueError(
-            f"Cannot find application '{name}' in {await self.package_directory()}."
+        return await self.find_in_package_directory(
+            paths=[["share", "applications"], ["squashfs-root"]],
+            name=f"{name}.desktop",
+            target_desc="application",
         )
 
     async def icon_paths(self, name: str) -> Iterable[Path]:
