@@ -1,8 +1,9 @@
 import configparser
 import hashlib
-import tempfile
+from io import StringIO
+from pathlib import Path
 
-from ..utils import CURRENT_DISTRIBUTION, CURRENT_OS, Optional, run
+from ..utils import Optional, raise_
 from .manual_version import ManualVersion
 
 
@@ -10,26 +11,28 @@ class YumRepo(ManualVersion):
     def __init__(
         self, yum_name: str, yum_url: str, gpg_key: Optional[str] = None, **kwargs
     ) -> None:
+        super().__init__(**kwargs)
         self.repo_name = yum_name
         self.baseurl = yum_url
         self.gpg_key = gpg_key
-        super().__init__(**kwargs)
 
     @property
     def name(self) -> str:
         return f"yum-{self.repo_name}"
 
-    def get_remote_version(self) -> str:
+    async def get_remote_version(self) -> str:
         m = hashlib.sha256()
         m.update(self.baseurl.encode())
         m.update((self.gpg_key or "").encode())
         return m.hexdigest()
 
-    def install(self) -> None:
-        if CURRENT_OS != "linux":
-            raise Exception("YumRepo is only supported on Linux")
-        if CURRENT_DISTRIBUTION != "fedora":
-            raise Exception("YumRepo is only supported on Fedora")
+    async def install(self) -> None:
+        (await self.driver.os()).switch_(
+            linux=lambda linux: lambda: None
+            if linux.distribution == "fedora"
+            else raise_(ValueError("YumRepo is only supported on Fedora")),
+            macos=lambda: raise_(ValueError("YumRepo is only supported on Linux")),
+        )()
 
         repo = configparser.ConfigParser()
         repo[self.repo_name] = {
@@ -41,19 +44,13 @@ class YumRepo(ManualVersion):
             repo[self.repo_name]["gpgcheck"] = "1"
             repo[self.repo_name]["gpgkey"] = self.gpg_key
 
-        with tempfile.NamedTemporaryFile(mode="w") as repo_file:
-            repo.write(repo_file, space_around_delimiters=False)
-            repo_file.flush()
-            run(
-                "sudo",
-                "install",
-                "--mode",
-                "644",
-                repo_file.name,
-                f"/etc/yum.repos.d/{self.repo_name}.repo",
-            )
+        contents = StringIO()
+        repo.write(contents, space_around_delimiters=False)
+        await self.driver.with_root(True).write_file(
+            Path(f"/etc/yum.repos.d/{self.repo_name}.repo"), contents.getvalue()
+        )
 
         if self.gpg_key:
-            run("sudo", "rpm", "--import", self.gpg_key)
+            await self.driver.with_root(True).run("rpm", "--import", self.gpg_key)
 
-        super().install()
+        await super().install()
